// container.cpp : Implementation of Ccontainer
#include "stdafx.h"
#include "Asp1701.h"
#include "container.h"

/////////////////////////////////////////////////////////////////////////////
// Ccontainer

HRESULT Ccontainer::Activate()
{
   HRESULT hr = S_OK;
   CComBSTR bstrObj;
   CComVariant vt;
   CComPtr<IGetContextProperties> pProps; //Context Properties

   IDispatch* piDispatch = NULL;

   // get ObjectContext
	hr = CoGetObjectContext(IID_IObjectContext, 
                             (void **)&m_spObjectContext);
   if (FAILED(hr))
      return hr;
   
   // get Context Properties
   hr = m_spObjectContext->QueryInterface( IID_IGetContextProperties, 
               (void**)&pProps );
   if (FAILED(hr)) 
       return hr;

   // get Response property
   bstrObj = "Response";
   hr = pProps->GetProperty( bstrObj, &vt ) ;

   if (FAILED(hr))
       return hr;

   piDispatch = vt. pdispVal;
   hr = piDispatch->QueryInterface( IID_IResponse, 
                     (void**)&m_piResponse );

   return hr;
} 

BOOL Ccontainer::CanBePooled()
{
	return TRUE;
} 

void Ccontainer::Deactivate()
{
    m_piResponse.Release();
	m_spObjectContext.Release();
} 


STDMETHODIMP Ccontainer::enumObjects(BSTR bstrContainer)
{
   HRESULT hr = S_OK;

   IADsGroup *pGroup;
   IADsMembers *   pADsMembers       = NULL;   
   IEnumVARIANT *  pEnumVariant      = NULL;  
   IUnknown *      pUnknown          = NULL; 
   IDispatch *pDisp                  = NULL;
   IADs *pADs                        = NULL;
   
   CComVariant vtout;
   CComVariant vtEntry;
   ULONG lng;

   // get group
   hr = ADsGetObject(bstrContainer,IID_IADsGroup,
                    (void **) &pGroup);

   // get members
   hr = pGroup->Members(&pADsMembers);
   if (FAILED(hr))
     return hr;
   pGroup->Release();

   // get enumerator
   hr = pADsMembers->get__NewEnum(&pUnknown);
   if (FAILED(hr))
       return hr;
   pADsMembers->Release();

   hr = pUnknown->QueryInterface(IID_IEnumVARIANT, (void **)&pEnumVariant);
   if (FAILED(hr))
       return hr;
   pUnknown->Release();

   // enumerate through entries, printing out "cn"
   while (S_OK == pEnumVariant->Next(1,&vtEntry,&lng)) {
        pDisp = V_DISPATCH(&vtEntry);
        pDisp->QueryInterface(IID_IADs, (void**)&pADs);
        pADs->Get(L"cn",&vtout);
        m_piResponse->Write(vtout);
        vtout = "<br>";
        m_piResponse->Write(vtout);

   }
   pEnumVariant->Release();

   return hr;
}

STDMETHODIMP Ccontainer::showUsers()
{
   HRESULT hr = S_OK;
   IADsContainer *pContainer;
   IEnumVARIANT *  pEnumVariant      = NULL;  
   ULONG lng;
   IDispatch *pDisp                  = NULL;
   IADs *pADs                        = NULL;
   CComVariant vtout;
   CComVariant vtEntry;

   // get group
   hr = ADsGetObject(L"LDAP://CN=Users,DC=development,DC=local",IID_IADsContainer,
                    (void **) &pContainer);

   // get enumerator
   hr = ADsBuildEnumerator(pContainer,&pEnumVariant);
   if (FAILED(hr))
       return hr;

   // enumerate through entries, printing out "cn"
   while (S_OK == ADsEnumerateNext(pEnumVariant,1,&vtEntry,&lng)) {
        V_DISPATCH(&vtEntry)->QueryInterface(IID_IADs, (void**)&pADs);
        pADs->Get(L"cn",&vtout);
        m_piResponse->Write(vtout);
        vtout = "<br>";
        m_piResponse->Write(vtout);

   }
   ADsFreeEnumerator(pEnumVariant);

   return hr;
}

STDMETHODIMP Ccontainer::enumObjectsByFilter(BSTR bstrFilter)
{
   HRESULT hr = S_OK;
   IADsContainer *pContainer;
   IEnumVARIANT *  pEnumVariant      = NULL;  
   ULONG lng;
   IDispatch *pDisp                  = NULL;
   IADs *pADs                        = NULL;
   CComVariant vtout;
   CComVariant vtEntry;
   VARIANT vtArray;
   CComBSTR bstrPath;

   // get users
   hr = ADsGetObject(L"LDAP://CN=Users,DC=development,DC=local",
                     IID_IADsContainer,
                     (void **) &pContainer);

 //  VariantInit(&vtArray);
   ADsBuildVarArrayStr(&(LPWSTR)bstrFilter,1,&vtArray);

   // filter
   pContainer->put_Filter(vtArray);

   // get enumerator
   hr = ADsBuildEnumerator(pContainer,&pEnumVariant);
   if (FAILED(hr))
       return hr;

   // enumerate through entries, printing out "cn"
   while (S_OK == ADsEnumerateNext(pEnumVariant,1,&vtEntry,&lng)) {
        V_DISPATCH(&vtEntry)->QueryInterface(IID_IADs, (void**)&pADs);
        pADs->get_ADsPath(&bstrPath);
        vtout.bstrVal = bstrPath.Detach(); 
        m_piResponse->Write(vtout);
        vtout = "<br>";
        m_piResponse->Write(vtout);

   }
   ADsFreeEnumerator(pEnumVariant);

   return hr;
}
