package perlasp;

# create object using anonymous hash
sub new {

    # Get the name of the class, always passed as first paren
    my $class = shift;

    # Get object reference
    my $self = {};

    # bless object and return
    return bless $self, ref($class) || $class;
}

# method to set Application object
sub setApp { 
  local($self, $name, $value) = @_;  
  
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $app = $obj->Item('Application');
  $app->Contents->SetProperty('Item',$name,$value);
}

# method to return value from Contents
sub getApp {
  local($self, $name) = @_;
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $app = $obj->Item('Application');
  $value = $app->Contents($name);

  return $value;
  } 

# method to get internationalization codes 
# from Session object
sub getInternational {

  # get Session
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $session = $obj->Item('Session');

  # get codes
  $locale = $session->LCID;
  $code = $session->CodePage;

  # add to string and return
  $strng = "LCID is $locale and CodePage is $code";

  return $strng;
  }

# set Contents collection items
sub setContents {
  local($self, $item1, $value1, $item2, $value2, $item3, $value3) = @_;
  
  # get Session object
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $session = $obj->Item('Session');

  # set contents
  $session->Contents->SetProperty('Item',$item1,$value1);
  $session->Contents->SetProperty('Item',$item2,$value2);

  # you can also use hash dereference to set item
  $session->Contents->{$item3} = $value3;
  }

# clear item from Contents
sub removeSessItem  {
  local($self, $item) = @_;

  # get Session object
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $session = $obj->Item('Session');

  $session->Contents->Remove($item);
  }

# clear all Session Contents items
sub removeAllSessItems {

  # get Session object
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $session = $obj->Item('Session');

  $session->Contents->RemoveAll();
  }

# setting Web cookies
sub setCookies {
  local($self, $cookie, $value, $expires) = @_;

  # get Response object
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $response = $obj->Item('Response');
  
  # set cookie
  $response->Cookies->SetProperty('Item', $cookie, $value);
  $response->Cookies($cookie)->{Expires} = $expires;
  
}

# working with buffered output
sub testBuffer {

  # get Response object
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $response = $obj->Item('Response');

  # start generating output
  $response->Write("<h1>First header</H1>");
  $response->Write("<h1>Second header</H1>");
  $response->Write("<h1>Third header</H1>");
  
  # now clear the buffer
  $response->Clear;

  # start generating output, again
  $response->Write("<h1>Fourth header</H1>");
  $response->Write("<h1>Fifth header</H1>");

  # now end processing
  $response->End;

  }

# process form values for POSTed form
sub getFormValues {

  # get Response and Request objects
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $response = $obj->Item('Response');
  $request = $obj->Item('Request');

  # get the two form values
  $firstname = $request->Form('firstname')->item;
  $lastname = $request->Form('lastname')->item;

  # output friendly message back to client
  $response->Write("<h1>Hello $firstname $lastname!</h1>");
}

# printing out each of the ServerVariables items
sub prntServerVariables {

  # get Request and Response
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $response = $obj->Item('Response');
  $request = $obj->Item('Request');

  # access ServerVariables collection as a list
  @lst = Win32::OLE::Enum->All($request->ServerVariables);

  # iterate through each list item, printing out
  # item name and its value
  $response->Write("<table border=2 cellspacing=0 cellpadding=10>");
  foreach my $item(@lst) {
   
    $response->Write("<tr>");
    $response->Write("<td valign=top>$item</td><td>" . 
               $request->ServerVariables($item)->item . "</td>");
    $response->Write("</tr>");
   }
  $response->Write("</table>"); 
}

# try out different encodings
sub encodeLine {
  local($self,$testline) = @_;

  # get Server and Response
  $mtx = Win32::OLE->new("MTxAS.AppServer.1");
  $obj = $mtx->GetObjectContext();
  $response = $obj->Item('Response');
  $server = $obj->Item('Server');

  # encode and print out 
  $strng = $server->HTMLEncode($testline);
  $response->Write("HTMLEncode results: $strng<p>");

  # encode and print out
  $strng = $server->URLEncode($testline);
  $response->Write("URLEncode is $strng<p>");

 }

  
  

1;